@@ -1,4 +1,4 @@
-//!	A library that provides a way to easily extract 1d ranges from a 2d container based off of the x or y axis statically through
+//! A library that provides a way to easily extract 1d ranges from a 2d container based off of the x or y axis statically through
 //! type parameters. This can help with performance in algorithms where you need to get values for a particular axis often.
 //!
 
@@ -9,14 +9,12 @@ mod ray;
 mod rect;
 mod vec2;
 
-
 #[cfg(feature = "std")]
 pub use roots;
 
 pub use num_traits;
 pub use partial_min_max;
 
-
 pub use self::range::range;
 pub use self::range::Range;
 pub use self::ray::ray;
@@ -30,7 +28,7 @@ pub use self::vec2::vec2same;
 pub use self::vec2::Vec2;
 
 ///The x axis implementation of the Axis
-#[derive(Eq,PartialEq,Copy, Clone,Debug)]
+#[derive(Eq, PartialEq, Copy, Clone, Debug)]
 pub struct XAXIS;
 impl Axis for XAXIS {
     type Next = YAXIS;
@@ -47,7 +45,7 @@ impl Axis for XAXIS {
 }
 
 ///The y axis implementation of the Axis
-#[derive(Eq,PartialEq,Copy, Clone,Debug)]
+#[derive(Eq, PartialEq, Copy, Clone, Debug)]
 pub struct YAXIS;
 impl Axis for YAXIS {
     type Next = XAXIS;
@@ -65,53 +63,40 @@ impl Axis for YAXIS {
     }
 }
 
-
 ///A dynamic axis as opposed to a statically known one via `impl Axis`.
-#[derive(Eq,PartialEq,Copy,Clone,Debug)]
-pub enum AxisDyn{
-    X(XAXIS),
-    Y(YAXIS)
+#[derive(Eq, PartialEq, Copy, Clone, Debug)]
+#[must_use]
+pub enum AxisDyn {
+    X,
+    Y,
 }
-impl AxisDyn{
+impl AxisDyn {
+    #[inline(always)]
+    #[must_use]
+    pub const fn is_equal_to(&self, other: AxisDyn) -> bool {
+        use AxisDyn::*;
+        matches!((self, other), (X, X) | (Y, Y))
+    }
 
     #[inline(always)]
-    pub fn is_axis(self)->bool{
-        match self{
-            AxisDyn::X(_)=>{
-                true
-            },
-            AxisDyn::Y(_)=>{
-                false
-            }
+    #[must_use]
+    pub const fn is_xaxis(self) -> bool {
+        match self {
+            AxisDyn::X => true,
+            AxisDyn::Y => false,
         }
     }
+
     #[inline(always)]
-    pub fn map_val<T>(self,val1:T,val2:T)->T{
-        match self{
-            AxisDyn::X(_)=>{
-                val1
-            },
-            AxisDyn::Y(_)=>{
-                val2
-            }
-        }
-    }
-    
-    #[inline(always)]
-    pub fn map<T>(self,func1:impl FnOnce(XAXIS)->T,func2:impl FnOnce(YAXIS)->T)->T{
-        match self{
-            AxisDyn::X(a)=>{
-                func1(a)
-            },
-            AxisDyn::Y(b)=>{
-                func2(b)
-            }
+    pub const fn next(&self) -> Self {
+        use AxisDyn::*;
+        match self {
+            X => Y,
+            Y => X,
         }
     }
 }
 
-
-
 ///Axis trait can be used to extract the x or y portions of a container.
 ///when you know the axis as compile time.
 ///The X implementation of this trait's Next associated trait is the Y implementation.
@@ -123,24 +108,17 @@ pub trait Axis: Sync + Send + Copy + Clone {
 
     ///Convert a statically known axis into a dynamic one.
     #[inline(always)]
-    fn to_dyn(&self)->AxisDyn{
-        if self.is_xaxis(){
-            AxisDyn::X(XAXIS)
-        }else{
-            AxisDyn::Y(YAXIS)
+    fn to_dyn(&self) -> AxisDyn {
+        if self.is_xaxis() {
+            AxisDyn::X
+        } else {
+            AxisDyn::Y
         }
     }
 
-
     #[inline(always)]
     #[must_use]
     fn is_equal_to<B: Axis>(&self, other: B) -> bool {
-        if self.is_xaxis() && other.is_xaxis() {
-            return true;
-        }
-        if !self.is_xaxis() && !other.is_xaxis() {
-            return true;
-        }
-        false
+        self.to_dyn().is_equal_to(other.to_dyn())
     }
 }
