@@ -7,17 +7,14 @@ pub fn range<T>(start: T, end: T) -> Range<T> {
 }
 
 ///A 1D range. Internally represented as start and end. (as opposed to a start and length)
-///This means that subdivision does not result in any floating point calculations.
-///The start value must be <= the end value.
+///If range A contains value x and range B contains value x, then A intersects B.
 ///There is no protection against "degenerate" Ranges where start>end.
-///Behavior of any of the functions with degenerate Ranges is unspecified.
 ///
 ///
-///A point is consindered inside of a range if the point is in [start,end), a semi-open interval.
+///A point is consindered inside of a range if the point is in [start,end].
 ///
 #[derive(Copy, Clone, Debug, Eq, PartialEq)]
 #[must_use]
-#[repr(C)]
 pub struct Range<T> {
     pub start: T,
     pub end: T,
@@ -25,32 +22,25 @@ pub struct Range<T> {
 
 impl<T> Range<T> {
     #[inline(always)]
-    #[must_use]
     pub fn new(start: T, end: T) -> Range<T> {
         Range { start, end }
     }
 }
 
-
-
-impl<B> From<[B;2]> for Range<B>{
+impl<B> From<[B; 2]> for Range<B> {
     #[inline(always)]
-    fn from(a:[B;2])->Self{
-        let [a,b]=a;
-        Range{start:a,end:b}
+    fn from(a: [B; 2]) -> Self {
+        let [a, b] = a;
+        Range { start: a, end: b }
     }
 }
-impl<B> From<Range<B>> for [B;2]{
+impl<B> From<Range<B>> for [B; 2] {
     #[inline(always)]
-    fn from(a:Range<B>)->Self{
-        [a.start,a.end]
+    fn from(a: Range<B>) -> Self {
+        [a.start, a.end]
     }
 }
 
-
-
-
-
 impl<T: Copy + Ord + core::ops::Sub<Output = T> + num_traits::sign::Signed> Range<T> {
     #[inline(always)]
     pub fn distance_to_point(&self, pos: T) -> Option<T> {
@@ -81,7 +71,7 @@ impl<T: Copy + PartialOrd> Range<T> {
     pub fn contains_ext(&self, pos: T) -> core::cmp::Ordering {
         if pos < self.start {
             core::cmp::Ordering::Less
-        } else if pos >= self.end {
+        } else if pos > self.end {
             core::cmp::Ordering::Greater
         } else {
             core::cmp::Ordering::Equal
@@ -138,10 +128,9 @@ impl<T: Copy + PartialOrd> Range<T> {
     ///Returns true if two ranges intersect.
     #[inline(always)]
     pub fn intersects(&self, val: &Range<T>) -> bool {
-        !(self.end<=val.start || val.end<=self.start)
+        !(self.end < val.start || val.end < self.start)
         //self.contains(val.start) || val.contains(self.start)
     }
-
 }
 
 #[cfg(test)]
@@ -152,17 +141,15 @@ mod tests {
     fn test_intersect() {
         let a = Range::new(0, 5);
         let b = Range::new(5, 6);
-        assert!(!a.intersects(&b));
-
-        let a = Range::new(0, 7);
-        let b = Range::new(4, 5);
         assert!(a.intersects(&b));
+        assert!(b.intersects(&a));
 
-
-        let a = Range::new(6, 7);
-        let b = Range::new(4, 6);
-        assert!(!a.intersects(&b));
+        assert!(a.contains(0));
+        assert!(a.contains(5));
+        assert!(b.contains(5));
+        assert!(b.contains(6));
     }
+
     #[test]
     fn test_range() {
         let a = Range::new(0, 5);
@@ -179,7 +166,6 @@ impl<T: Copy + core::ops::Sub<Output = T>> Range<T> {
 
 impl<T: Copy + core::ops::Sub<Output = T> + core::ops::Add<Output = T>> Range<T> {
     #[inline(always)]
-    #[must_use]
     pub fn grow(mut self, radius: T) -> Self {
         self.end = self.end + radius;
         self.start = self.start - radius;
@@ -188,26 +174,32 @@ impl<T: Copy + core::ops::Sub<Output = T> + core::ops::Add<Output = T>> Range<T>
 }
 
 impl<S> Range<S> {
-    
     #[inline(always)]
-    pub fn inner_as<B:'static+Copy>(self) -> Range<B> where S: num_traits::AsPrimitive<B>{
+    pub fn inner_as<B: 'static + Copy>(self) -> Range<B>
+    where
+        S: num_traits::AsPrimitive<B>,
+    {
         Range {
             start: self.start.as_(),
             end: self.end.as_(),
         }
     }
 
-
     #[inline(always)]
-    pub fn inner_into<A>(self) -> Range<A> where S:Into<A> {
+    pub fn inner_into<A>(self) -> Range<A>
+    where
+        S: Into<A>,
+    {
         let start = self.start.into();
         let end = self.end.into();
         Range { start, end }
     }
 
-
     #[inline(always)]
-    pub fn inner_try_into<A>(self) -> Result<Range<A>, S::Error> where S: TryInto<A> {
+    pub fn inner_try_into<A>(self) -> Result<Range<A>, S::Error>
+    where
+        S: TryInto<A>,
+    {
         let start = self.start.try_into();
         let end = self.end.try_into();
         match (start, end) {
